@@ -325,8 +325,8 @@ fprintf(stderr,
 	"    -oaddRuleLocation Add location of matching rule to metadata\n"
 	"    -oaddExecPath Add exec_path attribute to output\n"
 	"    -oaddOriginalMsg Always add original message to output, not just in error case\n"
-	"    -p           Print back only if the message has been parsed succesfully\n"
-	"    -P           Print back only if the message has NOT been parsed succesfully\n"
+	"    -p           Print back only if the message has been parsed successfully\n"
+	"    -P           Print back only if the message has NOT been parsed successfully\n"
 	"    -L           Add source file line number information to unparsed line output\n"
 	"    -t<tag>      Print back only messages matching the tag\n"
 	"    -v           Print debug. When used 3 times, prints parse DAG\n"
