@@ -1,15 +1,8 @@
+#!/bin/bash
 # added 2015-09-02 by Rainer Gerhards
 # This file is part of the liblognorm project, released under ASL 2.0
-
-uname -a | grep "SunOS.*5.10"
-if [ $? -eq 0 ] ; then
-   echo platform: `uname -a`
-   echo This looks like solaris 10, we disable known-failing tests to
-   echo permit OpenCSW to build packages. However, this are real failurs
-   echo and so a fix should be done as soon as time permits.
-   exit 77
-fi
 . $srcdir/exec.sh
+no_solaris10
 
 test_def $0 "string syntax"
 
